<p align="center">
    <a href="https://github.com/astral-sh/ruff" target="_blank">
        <img src="https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json" alt="Ruff">
    </a>
    <a href="https://badge.fury.io/py/git-ws-repo" target="_blank">
        <img src="https://badge.fury.io/py/git-ws-repo.svg" alt="PyPI Version">
    </a>
    <a href="https://github.com/c0fec0de/git-ws-repo/actions/workflows/main.yml" target="_blank">
        <img src="https://github.com/c0fec0de/git-ws-repo/actions/workflows/main.yml/badge.svg" alt="Python Build">
    </a>
    <a href="https://coveralls.io/github/c0fec0de/git-ws-repo?branch=main" target="_blank">
        <img src="https://coveralls.io/repos/github/c0fec0de/git-ws-repo/badge.svg?branch=main" alt="Coverage Status">
    </a>
    <a href="https://git-ws-repo.readthedocs.io/en/stable" target="_blank">
        <img src="https://readthedocs.org/projects/git-ws-repo/badge/?version=stable" alt="Documentation Build">
    </a>
    <a href="https://pypi.python.org/pypi/git-ws-repo" target="_blank">
        <img src="https://img.shields.io/pypi/pyversions/git-ws-repo.svg" alt="python-versions">
    </a>
</p>

<p align="center">
    <a href="https://git-ws-repo.readthedocs.io/en/stable/" target="_blank">Documentation</a>
    -
    <a href="https://pypi.org/project/git-ws-repo/" target="_blank">PyPI</a>
    -
    <a href="https://github.com/c0fec0de/git-ws-repo" target="_blank">Sources</a>
    -
    <a href="https://github.com/c0fec0de/git-ws-repo/issues" target="_blank">Issues</a>
</p>

# Google's git-repo replacement powered by git-ws-repo

TODO


## 📦 Installation

Git Workspace Repo is written in Python.

### Recommended

Please install python and then try:

```bash
curl -L https://github.com/pypa/pipx/releases/latest/download/pipx.pyz -o pipx.pyz && python3 pipx.pyz install git-ws-repo
```

Maybe you need run:

```bash
python3 pipx.pyz ensurepath
```

### via `pipx`

If you already installed `pipx` (https://pypa.github.io/pipx/installation/) just run:

```bash
pipx install git-ws-repo
```

Maybe you need run:

```bash
pipx ensurepath
```

### via `pip`

```bash
pip install git-ws-repo
```

For testing you can try:

```bash
repo --version
```
